==> zio-aws-storagegateway_3-5.17.104.1-sources.jar: zio/aws/storagegateway/model/RetrieveTapeRecoveryPointResponse.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.TapeARN
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class RetrieveTapeRecoveryPointResponse(
    tapeARN: Option[TapeARN] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.RetrieveTapeRecoveryPointResponse = {
    import RetrieveTapeRecoveryPointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.RetrieveTapeRecoveryPointResponse
      .builder()
      .optionallyWith(
        tapeARN.map(value => TapeARN.unwrap(value): java.lang.String)
      )(_.tapeARN)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.RetrieveTapeRecoveryPointResponse.ReadOnly =
    zio.aws.storagegateway.model.RetrieveTapeRecoveryPointResponse
      .wrap(buildAwsValue())
}
object RetrieveTapeRecoveryPointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.RetrieveTapeRecoveryPointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.storagegateway.model.RetrieveTapeRecoveryPointResponse =
      zio.aws.storagegateway.model
        .RetrieveTapeRecoveryPointResponse(tapeARN.map(value => value))
    def tapeARN: Option[TapeARN]
    def getTapeARN: ZIO[Any, AwsError, TapeARN] =
      AwsError.unwrapOptionField("tapeARN", tapeARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.RetrieveTapeRecoveryPointResponse
  ) extends zio.aws.storagegateway.model.RetrieveTapeRecoveryPointResponse.ReadOnly {
    override val tapeARN: Option[TapeARN] = scala
      .Option(impl.tapeARN())
      .map(value => zio.aws.storagegateway.model.primitives.TapeARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.RetrieveTapeRecoveryPointResponse
  ): zio.aws.storagegateway.model.RetrieveTapeRecoveryPointResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-storagegateway_3-5.20.7.3-sources.jar: zio/aws/storagegateway/model/RetrieveTapeRecoveryPointResponse.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.TapeARN
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class RetrieveTapeRecoveryPointResponse(
    tapeARN: Optional[TapeARN] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.RetrieveTapeRecoveryPointResponse = {
    import RetrieveTapeRecoveryPointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.RetrieveTapeRecoveryPointResponse
      .builder()
      .optionallyWith(
        tapeARN.map(value => TapeARN.unwrap(value): java.lang.String)
      )(_.tapeARN)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.RetrieveTapeRecoveryPointResponse.ReadOnly =
    zio.aws.storagegateway.model.RetrieveTapeRecoveryPointResponse
      .wrap(buildAwsValue())
}
object RetrieveTapeRecoveryPointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.RetrieveTapeRecoveryPointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.storagegateway.model.RetrieveTapeRecoveryPointResponse =
      zio.aws.storagegateway.model
        .RetrieveTapeRecoveryPointResponse(tapeARN.map(value => value))
    def tapeARN: Optional[TapeARN]
    def getTapeARN: ZIO[Any, AwsError, TapeARN] =
      AwsError.unwrapOptionField("tapeARN", tapeARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.RetrieveTapeRecoveryPointResponse
  ) extends zio.aws.storagegateway.model.RetrieveTapeRecoveryPointResponse.ReadOnly {
    override val tapeARN: Optional[TapeARN] = zio.aws.core.internal
      .optionalFromNullable(impl.tapeARN())
      .map(value => zio.aws.storagegateway.model.primitives.TapeARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.RetrieveTapeRecoveryPointResponse
  ): zio.aws.storagegateway.model.RetrieveTapeRecoveryPointResponse.ReadOnly =
    new Wrapper(impl)
}
